@@ -3,13 +3,13 @@ use warnings;
 use strict;
 use 5.10.0;
 
-use Term::Form;
+use Term::Form::ReadLine;
 
 use FindBin qw( $RealBin );
 use lib $RealBin;
 use Data_Test_Readline;
 
-my $tiny = Term::Form->new();
+my $tiny = Term::Form::ReadLine->new();
 
 my $a_ref = Data_Test_Readline::return_test_data();
 
